@@ -11,7 +11,7 @@ use List::Util qw(shuffle);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-07-22'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.282'; # VERSION
+our $VERSION = '0.283'; # VERSION
 
 our %SPEC;
 
@@ -411,6 +411,48 @@ _
         },
     ],
     'cmdline.default_format' => 'text-simple',
+    'x.doc.faq' => <<'_',
+
+## How to select multiple wordlists? It's cumbersome having to -w WORDLIST1 -w WORDLIST2 and so on!
+
+You can specify wildcard in `-w` option, e.g. if you want to include all English
+wordlists you can use `-w EN::*` or `-w EN::**` (`**` recurses while `*` only
+matches one level deep).
+
+Or you can also use `-b` option. Some people bundle wordlists together and put
+them up on CPAN in the `Acme::CPANModules::WordListBundle::*` namespace. You can
+install those modules first then use the wordlist bundle.
+
+## Can `wordlist` help me solve Wordle?
+
+Yes, using regex or the `--chars-ordered` and `--chars-unordered` options. For
+example, if you have:
+
+    T W _ S _
+
+(3 letters with the correct position), you can use:
+
+    % wordlist -w EN::Enable '/^tw.s./' --len 5
+    twist
+
+or:
+
+    % wordlist -w EN::Enable --chars-ordered tws --len 5
+    tawse
+    thaws
+    ...
+    twist
+    twits
+
+Another example, if you have:
+
+    W* T* _ S _
+
+(2 letters with the incorrect position and 1 letter in the correct position),
+you can use:
+
+    % wordlist -w EN::Enable --chars-unordered wts --len 5 '/^...s.$/'
+_
 };
 sub wordlist {
     require Encode;
@@ -701,7 +743,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.282 of App::wordlist (from Perl distribution App-wordlist), released on 2022-07-22.
+This document describes version 0.283 of App::wordlist (from Perl distribution App-wordlist), released on 2022-07-22.
 
 =head1 SYNOPSIS
 
@@ -746,6 +788,18 @@ Examples:
 
  wordlist(arg => ["foo"], wordlists => ["ID::**"]);
 
+=item * Select a bunch of wordlists via wordlist bundle (Acme::CPANModules::WordListBundle::* module):
+
+ wordlist(arg => ["foo"], wordlist_bundles => ["Proverbs"]);
+
+=item * An alternative to select all proverb wordlists:
+
+ wordlist(arg => ["foo"], wordlists => ["Phrase::**::Proverb::**"]);
+
+=item * Check to see which wordlists we are selecting via `-w` with wildcards or via `-b`:
+
+ wordlist(action => "list_selected", wordlists => ["Phrase::**::Proverb::**"]);
+
 =item * Print all words from EN::Enable wordlist that are 6 characters long and have the letters BOBLEG (in no particular order); great for cheats in word forming games:
 
  wordlist(
